import isPropValid from '@emotion/is-prop-valid';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _objectSpread from '@babel/runtime/helpers/objectSpread';
import _typeof from '@babel/runtime/helpers/typeof';
import { cache, css } from 'emotion';
export * from 'emotion';
import { getRegisteredStyles } from '@emotion/utils';

var testOmitPropsOnStringTag = function testOmitPropsOnStringTag(prop) {
  return isPropValid(prop);
};

var testOmitPropsOnComponent = function testOmitPropsOnComponent(key) {
  return key !== 'theme' && key !== 'ref';
};

var getDefaultShouldForwardProp = function getDefaultShouldForwardProp(tag) {
  return typeof tag === 'string' && // 96 is one less than the char code
  // for "a" so this is checking that
  // it's a lowercase character
  tag.charCodeAt(0) > 96 ? testOmitPropsOnStringTag : testOmitPropsOnComponent;
};

function capitalizeFirstLetter(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}

function stringifyClass(klass) {
  if (Array.isArray(klass)) {
    return klass.join(' ');
  }

  if (_typeof(klass) === 'object') {
    return Object.keys(klass).filter(function (key) {
      return Boolean(klass[key]);
    }).join(' ');
  }

  return klass;
}

function createStyled(tag, options) {
  var identifierName;
  var shouldForwardProp;
  var targetClassName;
  var props;

  if (options !== undefined) {
    identifierName = options.label;
    targetClassName = options.target;
    props = _objectSpread({}, tag.props || {}, options.props || {});
    shouldForwardProp = tag.__emotion_forwardProp && options.shouldForwardProp ? function (propName) {
      return tag.__emotion_forwardProp(propName) && options.shouldForwardProp(propName);
    } : options.shouldForwardProp;
  }

  var isReal = tag.__emotion_real === tag;
  var baseTag = isReal && tag.__emotion_base || tag;

  if (typeof shouldForwardProp !== 'function' && isReal) {
    shouldForwardProp = tag.__emotion_forwardProp;
  }

  var defaultShouldForwardProp = shouldForwardProp || getDefaultShouldForwardProp(baseTag);
  var shouldUseAs = !defaultShouldForwardProp('as');
  return function () {
    var styles = isReal && tag.__emotion_styles !== undefined ? tag.__emotion_styles.slice(0) : [];

    if (identifierName !== undefined) {
      styles.push("label:".concat(identifierName, ";"));
    }

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    if (args[0] == null || args[0].raw === undefined) {
      styles.push.apply(styles, args);
    } else {
      styles.push(args[0][0]);
      var len = args.length;
      var i = 1;

      for (; i < len; i++) {
        styles.push(args[i], args[0][i]);
      }
    }

    var displayName = "Styled".concat(tag.name || identifierName || typeof tag === 'string' && capitalizeFirstLetter(tag) || 'Component');
    var Styled = {
      name: displayName,
      inject: {
        theme: {
          default: null
        }
      },
      functional: true,
      props: props,
      render: function render(createElement, _ref) {
        var props = _ref.props,
            data = _ref.data,
            children = _ref.children,
            injections = _ref.injections;
        var _data$attrs = data.attrs,
            attrs = _data$attrs === void 0 ? {} : _data$attrs;
        var finalTag = attrs.as || baseTag;
        var className = '';
        var classInterpolations = [];
        var mergedProps = props;

        for (var key in props) {
          mergedProps[key] = props[key];
        }

        mergedProps.theme = attrs.theme || injections.theme;
        var existingClasses = stringifyClass(data.class);

        if (existingClasses) {
          className += getRegisteredStyles(cache.registered, classInterpolations, existingClasses);
        }

        var context = {
          mergedProps: mergedProps
        };
        className +=
        /*#__PURE__*/
        css.apply(context, styles.concat(classInterpolations));

        if (targetClassName !== undefined) {
          className += " ".concat(targetClassName);
        }

        var finalShouldForwardProp = shouldUseAs && shouldForwardProp === undefined ? getDefaultShouldForwardProp(finalTag) : defaultShouldForwardProp;
        var newProps = {};
        var newAttrs = {};
        var newDomProps = {};

        for (var _key2 in props) {
          if (_key2 === 'as') continue;

          if (finalShouldForwardProp(_key2)) {
            newProps[_key2] = props[_key2];
            newAttrs[_key2] = props[_key2];
          }
        }

        for (var _key3 in attrs) {
          if (_key3 === 'as' || _key3 === 'theme') continue;

          if (_key3 === 'value') {
            newDomProps[_key3] = attrs[_key3];
          } else {
            newAttrs[_key3] = attrs[_key3];
          }
        } // https://vuejs.org/v2/guide/render-function.html#createElement-Arguments


        var newData = _objectSpread({}, data, {
          attrs: newAttrs,
          props: newProps,
          domProps: newDomProps,
          class: className
        });

        return createElement(finalTag, newData, children);
      }
    };
    Styled.__emotion_real = Styled;
    Styled.__emotion_base = baseTag;
    Styled.__emotion_styles = styles;
    Styled.__emotion_forwardProp = shouldForwardProp;
    Object.defineProperty(Styled, 'toString', {
      enumerable: false,
      value: function value() {
        if (targetClassName === undefined && process.env.NODE_ENV !== 'production') {
          return 'NO_COMPONENT_SELECTOR';
        }

        return ".".concat(targetClassName);
      }
    });

    Styled.withComponent = function (nextTag, nextOptions) {
      return createStyled(nextTag, nextOptions !== undefined ? _objectSpread({}, options || {}, nextOptions) : options).apply(void 0, _toConsumableArray(styles));
    };

    return Styled;
  };
}

export default createStyled;
